@@ -29,6 +29,7 @@ import subprocess
 import shutil
 from threading import Timer
 from six import text_type
+from requests.exceptions import HTTPError
 
 from odcs.server import conf, log
 
@@ -59,6 +60,8 @@ def retry(
                 try:
                     return function(*args, **kwargs)
                 except wait_on as e:
+                    if isinstance(e, HTTPError) and e.response.status_code == 404:
+                        raise
                     if logger is not None:
                         logger.warn(
                             "Exception %r raised from %r.  Retry in %rs",
@@ -86,7 +89,8 @@ def makedirs(path, mode=0o775):
 def _kill_process_group(proc, args):
     log.error("Timeout occured while running: %s", args)
     pgrp = os.getpgid(proc.pid)
-    os.killpg(pgrp, signal.SIGINT)
+    log.info("Sending SIGTERM to group %s of process %s" % (pgrp, proc.pid))
+    os.killpg(pgrp, signal.SIGTERM)
 
 
 def execute_cmd(args, stdout=None, stderr=None, cwd=None, timeout=None):
@@ -129,7 +133,7 @@ def execute_cmd(args, stdout=None, stderr=None, cwd=None, timeout=None):
     finally:
         timeout_expired = False
         if timeout:
-            if timeout_timer.finished.is_set():
+            if timeout_timer.finished.wait(0.01):
                 timeout_expired = True
             timeout_timer.cancel()
 
